# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/feegrant/v1beta1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cosmos/feegrant/v1beta1/tx.proto',
  package='cosmos.feegrant.v1beta1',
  syntax='proto3',
  serialized_options=b'Z\'github.com/cosmos/cosmos-sdk/x/feegrant',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n cosmos/feegrant/v1beta1/tx.proto\x12\x17\x63osmos.feegrant.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a\x19\x63osmos_proto/cosmos.proto\"q\n\x11MsgGrantAllowance\x12\x0f\n\x07granter\x18\x01 \x01(\t\x12\x0f\n\x07grantee\x18\x02 \x01(\t\x12:\n\tallowance\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyB\x11\xca\xb4-\rFeeAllowanceI\"\x1b\n\x19MsgGrantAllowanceResponse\"6\n\x12MsgRevokeAllowance\x12\x0f\n\x07granter\x18\x01 \x01(\t\x12\x0f\n\x07grantee\x18\x02 \x01(\t\"\x1c\n\x1aMsgRevokeAllowanceResponse2\xec\x01\n\x03Msg\x12p\n\x0eGrantAllowance\x12*.cosmos.feegrant.v1beta1.MsgGrantAllowance\x1a\x32.cosmos.feegrant.v1beta1.MsgGrantAllowanceResponse\x12s\n\x0fRevokeAllowance\x12+.cosmos.feegrant.v1beta1.MsgRevokeAllowance\x1a\x33.cosmos.feegrant.v1beta1.MsgRevokeAllowanceResponseB)Z\'github.com/cosmos/cosmos-sdk/x/feegrantb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,cosmos__proto_dot_cosmos__pb2.DESCRIPTOR,])




_MSGGRANTALLOWANCE = _descriptor.Descriptor(
  name='MsgGrantAllowance',
  full_name='cosmos.feegrant.v1beta1.MsgGrantAllowance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='granter', full_name='cosmos.feegrant.v1beta1.MsgGrantAllowance.granter', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grantee', full_name='cosmos.feegrant.v1beta1.MsgGrantAllowance.grantee', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allowance', full_name='cosmos.feegrant.v1beta1.MsgGrantAllowance.allowance', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\312\264-\rFeeAllowanceI', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=137,
  serialized_end=250,
)


_MSGGRANTALLOWANCERESPONSE = _descriptor.Descriptor(
  name='MsgGrantAllowanceResponse',
  full_name='cosmos.feegrant.v1beta1.MsgGrantAllowanceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=252,
  serialized_end=279,
)


_MSGREVOKEALLOWANCE = _descriptor.Descriptor(
  name='MsgRevokeAllowance',
  full_name='cosmos.feegrant.v1beta1.MsgRevokeAllowance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='granter', full_name='cosmos.feegrant.v1beta1.MsgRevokeAllowance.granter', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grantee', full_name='cosmos.feegrant.v1beta1.MsgRevokeAllowance.grantee', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=281,
  serialized_end=335,
)


_MSGREVOKEALLOWANCERESPONSE = _descriptor.Descriptor(
  name='MsgRevokeAllowanceResponse',
  full_name='cosmos.feegrant.v1beta1.MsgRevokeAllowanceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=337,
  serialized_end=365,
)

_MSGGRANTALLOWANCE.fields_by_name['allowance'].message_type = google_dot_protobuf_dot_any__pb2._ANY
DESCRIPTOR.message_types_by_name['MsgGrantAllowance'] = _MSGGRANTALLOWANCE
DESCRIPTOR.message_types_by_name['MsgGrantAllowanceResponse'] = _MSGGRANTALLOWANCERESPONSE
DESCRIPTOR.message_types_by_name['MsgRevokeAllowance'] = _MSGREVOKEALLOWANCE
DESCRIPTOR.message_types_by_name['MsgRevokeAllowanceResponse'] = _MSGREVOKEALLOWANCERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MsgGrantAllowance = _reflection.GeneratedProtocolMessageType('MsgGrantAllowance', (_message.Message,), {
  'DESCRIPTOR' : _MSGGRANTALLOWANCE,
  '__module__' : 'cosmos.feegrant.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.feegrant.v1beta1.MsgGrantAllowance)
  })
_sym_db.RegisterMessage(MsgGrantAllowance)

MsgGrantAllowanceResponse = _reflection.GeneratedProtocolMessageType('MsgGrantAllowanceResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGGRANTALLOWANCERESPONSE,
  '__module__' : 'cosmos.feegrant.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.feegrant.v1beta1.MsgGrantAllowanceResponse)
  })
_sym_db.RegisterMessage(MsgGrantAllowanceResponse)

MsgRevokeAllowance = _reflection.GeneratedProtocolMessageType('MsgRevokeAllowance', (_message.Message,), {
  'DESCRIPTOR' : _MSGREVOKEALLOWANCE,
  '__module__' : 'cosmos.feegrant.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.feegrant.v1beta1.MsgRevokeAllowance)
  })
_sym_db.RegisterMessage(MsgRevokeAllowance)

MsgRevokeAllowanceResponse = _reflection.GeneratedProtocolMessageType('MsgRevokeAllowanceResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGREVOKEALLOWANCERESPONSE,
  '__module__' : 'cosmos.feegrant.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.feegrant.v1beta1.MsgRevokeAllowanceResponse)
  })
_sym_db.RegisterMessage(MsgRevokeAllowanceResponse)


DESCRIPTOR._options = None
_MSGGRANTALLOWANCE.fields_by_name['allowance']._options = None

_MSG = _descriptor.ServiceDescriptor(
  name='Msg',
  full_name='cosmos.feegrant.v1beta1.Msg',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=368,
  serialized_end=604,
  methods=[
  _descriptor.MethodDescriptor(
    name='GrantAllowance',
    full_name='cosmos.feegrant.v1beta1.Msg.GrantAllowance',
    index=0,
    containing_service=None,
    input_type=_MSGGRANTALLOWANCE,
    output_type=_MSGGRANTALLOWANCERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RevokeAllowance',
    full_name='cosmos.feegrant.v1beta1.Msg.RevokeAllowance',
    index=1,
    containing_service=None,
    input_type=_MSGREVOKEALLOWANCE,
    output_type=_MSGREVOKEALLOWANCERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_MSG)

DESCRIPTOR.services_by_name['Msg'] = _MSG

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_meta_rpc.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='exchange/injective_meta_rpc.proto',
  package='injective_meta_rpc',
  syntax='proto3',
  serialized_options=b'Z\025/injective_meta_rpcpb',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!exchange/injective_meta_rpc.proto\x12\x12injective_meta_rpc\"\r\n\x0bPingRequest\"\x0e\n\x0cPingResponse\"\x10\n\x0eVersionRequest\"\x8f\x01\n\x0fVersionResponse\x12\x0f\n\x07version\x18\x01 \x01(\t\x12=\n\x05\x62uild\x18\x02 \x03(\x0b\x32..injective_meta_rpc.VersionResponse.BuildEntry\x1a,\n\nBuildEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\" \n\x0bInfoRequest\x12\x11\n\ttimestamp\x18\x01 \x01(\x12\"\xc1\x01\n\x0cInfoResponse\x12\x11\n\ttimestamp\x18\x01 \x01(\x12\x12\x13\n\x0bserver_time\x18\x02 \x01(\x12\x12\x0f\n\x07version\x18\x03 \x01(\t\x12:\n\x05\x62uild\x18\x04 \x03(\x0b\x32+.injective_meta_rpc.InfoResponse.BuildEntry\x12\x0e\n\x06region\x18\x05 \x01(\t\x1a,\n\nBuildEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x18\n\x16StreamKeepaliveRequest\"Q\n\x17StreamKeepaliveResponse\x12\r\n\x05\x65vent\x18\x01 \x01(\t\x12\x14\n\x0cnew_endpoint\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x12\x32\xea\x02\n\x10InjectiveMetaRPC\x12I\n\x04Ping\x12\x1f.injective_meta_rpc.PingRequest\x1a .injective_meta_rpc.PingResponse\x12R\n\x07Version\x12\".injective_meta_rpc.VersionRequest\x1a#.injective_meta_rpc.VersionResponse\x12I\n\x04Info\x12\x1f.injective_meta_rpc.InfoRequest\x1a .injective_meta_rpc.InfoResponse\x12l\n\x0fStreamKeepalive\x12*.injective_meta_rpc.StreamKeepaliveRequest\x1a+.injective_meta_rpc.StreamKeepaliveResponse0\x01\x42\x17Z\x15/injective_meta_rpcpbb\x06proto3'
)




_PINGREQUEST = _descriptor.Descriptor(
  name='PingRequest',
  full_name='injective_meta_rpc.PingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=57,
  serialized_end=70,
)


_PINGRESPONSE = _descriptor.Descriptor(
  name='PingResponse',
  full_name='injective_meta_rpc.PingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=72,
  serialized_end=86,
)


_VERSIONREQUEST = _descriptor.Descriptor(
  name='VersionRequest',
  full_name='injective_meta_rpc.VersionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=88,
  serialized_end=104,
)


_VERSIONRESPONSE_BUILDENTRY = _descriptor.Descriptor(
  name='BuildEntry',
  full_name='injective_meta_rpc.VersionResponse.BuildEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='injective_meta_rpc.VersionResponse.BuildEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='injective_meta_rpc.VersionResponse.BuildEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=206,
  serialized_end=250,
)

_VERSIONRESPONSE = _descriptor.Descriptor(
  name='VersionResponse',
  full_name='injective_meta_rpc.VersionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='injective_meta_rpc.VersionResponse.version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='build', full_name='injective_meta_rpc.VersionResponse.build', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_VERSIONRESPONSE_BUILDENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=107,
  serialized_end=250,
)


_INFOREQUEST = _descriptor.Descriptor(
  name='InfoRequest',
  full_name='injective_meta_rpc.InfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='injective_meta_rpc.InfoRequest.timestamp', index=0,
      number=1, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=252,
  serialized_end=284,
)


_INFORESPONSE_BUILDENTRY = _descriptor.Descriptor(
  name='BuildEntry',
  full_name='injective_meta_rpc.InfoResponse.BuildEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='injective_meta_rpc.InfoResponse.BuildEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='injective_meta_rpc.InfoResponse.BuildEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=206,
  serialized_end=250,
)

_INFORESPONSE = _descriptor.Descriptor(
  name='InfoResponse',
  full_name='injective_meta_rpc.InfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='injective_meta_rpc.InfoResponse.timestamp', index=0,
      number=1, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server_time', full_name='injective_meta_rpc.InfoResponse.server_time', index=1,
      number=2, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='injective_meta_rpc.InfoResponse.version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='build', full_name='injective_meta_rpc.InfoResponse.build', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='region', full_name='injective_meta_rpc.InfoResponse.region', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_INFORESPONSE_BUILDENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=287,
  serialized_end=480,
)


_STREAMKEEPALIVEREQUEST = _descriptor.Descriptor(
  name='StreamKeepaliveRequest',
  full_name='injective_meta_rpc.StreamKeepaliveRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=482,
  serialized_end=506,
)


_STREAMKEEPALIVERESPONSE = _descriptor.Descriptor(
  name='StreamKeepaliveResponse',
  full_name='injective_meta_rpc.StreamKeepaliveResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event', full_name='injective_meta_rpc.StreamKeepaliveResponse.event', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_endpoint', full_name='injective_meta_rpc.StreamKeepaliveResponse.new_endpoint', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='injective_meta_rpc.StreamKeepaliveResponse.timestamp', index=2,
      number=3, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=508,
  serialized_end=589,
)

_VERSIONRESPONSE_BUILDENTRY.containing_type = _VERSIONRESPONSE
_VERSIONRESPONSE.fields_by_name['build'].message_type = _VERSIONRESPONSE_BUILDENTRY
_INFORESPONSE_BUILDENTRY.containing_type = _INFORESPONSE
_INFORESPONSE.fields_by_name['build'].message_type = _INFORESPONSE_BUILDENTRY
DESCRIPTOR.message_types_by_name['PingRequest'] = _PINGREQUEST
DESCRIPTOR.message_types_by_name['PingResponse'] = _PINGRESPONSE
DESCRIPTOR.message_types_by_name['VersionRequest'] = _VERSIONREQUEST
DESCRIPTOR.message_types_by_name['VersionResponse'] = _VERSIONRESPONSE
DESCRIPTOR.message_types_by_name['InfoRequest'] = _INFOREQUEST
DESCRIPTOR.message_types_by_name['InfoResponse'] = _INFORESPONSE
DESCRIPTOR.message_types_by_name['StreamKeepaliveRequest'] = _STREAMKEEPALIVEREQUEST
DESCRIPTOR.message_types_by_name['StreamKeepaliveResponse'] = _STREAMKEEPALIVERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PingRequest = _reflection.GeneratedProtocolMessageType('PingRequest', (_message.Message,), {
  'DESCRIPTOR' : _PINGREQUEST,
  '__module__' : 'exchange.injective_meta_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_meta_rpc.PingRequest)
  })
_sym_db.RegisterMessage(PingRequest)

PingResponse = _reflection.GeneratedProtocolMessageType('PingResponse', (_message.Message,), {
  'DESCRIPTOR' : _PINGRESPONSE,
  '__module__' : 'exchange.injective_meta_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_meta_rpc.PingResponse)
  })
_sym_db.RegisterMessage(PingResponse)

VersionRequest = _reflection.GeneratedProtocolMessageType('VersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _VERSIONREQUEST,
  '__module__' : 'exchange.injective_meta_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_meta_rpc.VersionRequest)
  })
_sym_db.RegisterMessage(VersionRequest)

VersionResponse = _reflection.GeneratedProtocolMessageType('VersionResponse', (_message.Message,), {

  'BuildEntry' : _reflection.GeneratedProtocolMessageType('BuildEntry', (_message.Message,), {
    'DESCRIPTOR' : _VERSIONRESPONSE_BUILDENTRY,
    '__module__' : 'exchange.injective_meta_rpc_pb2'
    # @@protoc_insertion_point(class_scope:injective_meta_rpc.VersionResponse.BuildEntry)
    })
  ,
  'DESCRIPTOR' : _VERSIONRESPONSE,
  '__module__' : 'exchange.injective_meta_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_meta_rpc.VersionResponse)
  })
_sym_db.RegisterMessage(VersionResponse)
_sym_db.RegisterMessage(VersionResponse.BuildEntry)

InfoRequest = _reflection.GeneratedProtocolMessageType('InfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _INFOREQUEST,
  '__module__' : 'exchange.injective_meta_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_meta_rpc.InfoRequest)
  })
_sym_db.RegisterMessage(InfoRequest)

InfoResponse = _reflection.GeneratedProtocolMessageType('InfoResponse', (_message.Message,), {

  'BuildEntry' : _reflection.GeneratedProtocolMessageType('BuildEntry', (_message.Message,), {
    'DESCRIPTOR' : _INFORESPONSE_BUILDENTRY,
    '__module__' : 'exchange.injective_meta_rpc_pb2'
    # @@protoc_insertion_point(class_scope:injective_meta_rpc.InfoResponse.BuildEntry)
    })
  ,
  'DESCRIPTOR' : _INFORESPONSE,
  '__module__' : 'exchange.injective_meta_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_meta_rpc.InfoResponse)
  })
_sym_db.RegisterMessage(InfoResponse)
_sym_db.RegisterMessage(InfoResponse.BuildEntry)

StreamKeepaliveRequest = _reflection.GeneratedProtocolMessageType('StreamKeepaliveRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMKEEPALIVEREQUEST,
  '__module__' : 'exchange.injective_meta_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_meta_rpc.StreamKeepaliveRequest)
  })
_sym_db.RegisterMessage(StreamKeepaliveRequest)

StreamKeepaliveResponse = _reflection.GeneratedProtocolMessageType('StreamKeepaliveResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMKEEPALIVERESPONSE,
  '__module__' : 'exchange.injective_meta_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_meta_rpc.StreamKeepaliveResponse)
  })
_sym_db.RegisterMessage(StreamKeepaliveResponse)


DESCRIPTOR._options = None
_VERSIONRESPONSE_BUILDENTRY._options = None
_INFORESPONSE_BUILDENTRY._options = None

_INJECTIVEMETARPC = _descriptor.ServiceDescriptor(
  name='InjectiveMetaRPC',
  full_name='injective_meta_rpc.InjectiveMetaRPC',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=592,
  serialized_end=954,
  methods=[
  _descriptor.MethodDescriptor(
    name='Ping',
    full_name='injective_meta_rpc.InjectiveMetaRPC.Ping',
    index=0,
    containing_service=None,
    input_type=_PINGREQUEST,
    output_type=_PINGRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Version',
    full_name='injective_meta_rpc.InjectiveMetaRPC.Version',
    index=1,
    containing_service=None,
    input_type=_VERSIONREQUEST,
    output_type=_VERSIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Info',
    full_name='injective_meta_rpc.InjectiveMetaRPC.Info',
    index=2,
    containing_service=None,
    input_type=_INFOREQUEST,
    output_type=_INFORESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamKeepalive',
    full_name='injective_meta_rpc.InjectiveMetaRPC.StreamKeepalive',
    index=3,
    containing_service=None,
    input_type=_STREAMKEEPALIVEREQUEST,
    output_type=_STREAMKEEPALIVERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_INJECTIVEMETARPC)

DESCRIPTOR.services_by_name['InjectiveMetaRPC'] = _INJECTIVEMETARPC

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/peggy/v1/events.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from injective.peggy.v1 import attestation_pb2 as injective_dot_peggy_dot_v1_dot_attestation__pb2
from injective.peggy.v1 import types_pb2 as injective_dot_peggy_dot_v1_dot_types__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='injective/peggy/v1/events.proto',
  package='injective.peggy.v1',
  syntax='proto3',
  serialized_options=b'ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1finjective/peggy/v1/events.proto\x12\x12injective.peggy.v1\x1a\x14gogoproto/gogo.proto\x1a$injective/peggy/v1/attestation.proto\x1a\x1einjective/peggy/v1/types.proto\"\xac\x01\n\x18\x45ventAttestationObserved\x12\x37\n\x10\x61ttestation_type\x18\x01 \x01(\x0e\x32\x1d.injective.peggy.v1.ClaimType\x12\x17\n\x0f\x62ridge_contract\x18\x02 \x01(\t\x12\x17\n\x0f\x62ridge_chain_id\x18\x03 \x01(\x04\x12\x16\n\x0e\x61ttestation_id\x18\x04 \x01(\x0c\x12\r\n\x05nonce\x18\x05 \x01(\x04\"O\n\x1b\x45ventBridgeWithdrawCanceled\x12\x17\n\x0f\x62ridge_contract\x18\x01 \x01(\t\x12\x17\n\x0f\x62ridge_chain_id\x18\x02 \x01(\x04\"\x83\x01\n\x12\x45ventOutgoingBatch\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x1c\n\x14orchestrator_address\x18\x02 \x01(\t\x12\x13\n\x0b\x62\x61tch_nonce\x18\x03 \x01(\x04\x12\x15\n\rbatch_timeout\x18\x04 \x01(\x04\x12\x14\n\x0c\x62\x61tch_tx_ids\x18\x05 \x03(\x04\"o\n\x1a\x45ventOutgoingBatchCanceled\x12\x17\n\x0f\x62ridge_contract\x18\x01 \x01(\t\x12\x17\n\x0f\x62ridge_chain_id\x18\x02 \x01(\x04\x12\x10\n\x08\x62\x61tch_id\x18\x03 \x01(\x04\x12\r\n\x05nonce\x18\x04 \x01(\x04\"\xe1\x01\n\x18\x45ventValsetUpdateRequest\x12\x14\n\x0cvalset_nonce\x18\x01 \x01(\x04\x12\x15\n\rvalset_height\x18\x02 \x01(\x04\x12;\n\x0evalset_members\x18\x03 \x03(\x0b\x32#.injective.peggy.v1.BridgeValidator\x12\x45\n\rreward_amount\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12\x14\n\x0creward_token\x18\x05 \x01(\t\"v\n\x1d\x45ventSetOrchestratorAddresses\x12\x19\n\x11validator_address\x18\x01 \x01(\t\x12\x1c\n\x14orchestrator_address\x18\x02 \x01(\t\x12\x1c\n\x14operator_eth_address\x18\x03 \x01(\t\"H\n\x12\x45ventValsetConfirm\x12\x14\n\x0cvalset_nonce\x18\x01 \x01(\x04\x12\x1c\n\x14orchestrator_address\x18\x02 \x01(\t\"\xd0\x01\n\x0e\x45ventSendToEth\x12\x16\n\x0eoutgoing_tx_id\x18\x01 \x01(\x04\x12\x0e\n\x06sender\x18\x02 \x01(\t\x12\x10\n\x08receiver\x18\x03 \x01(\t\x12?\n\x06\x61mount\x18\x04 \x01(\tB/\xda\xde\x1f\'github.com/cosmos/cosmos-sdk/types.Coin\xc8\xde\x1f\x00\x12\x43\n\nbridge_fee\x18\x05 \x01(\tB/\xda\xde\x1f\'github.com/cosmos/cosmos-sdk/types.Coin\xc8\xde\x1f\x00\"F\n\x11\x45ventConfirmBatch\x12\x13\n\x0b\x62\x61tch_nonce\x18\x01 \x01(\x04\x12\x1c\n\x14orchestrator_address\x18\x02 \x01(\t\"R\n\x14\x45ventAttestationVote\x12\x13\n\x0b\x65vent_nonce\x18\x01 \x01(\x04\x12\x16\n\x0e\x61ttestation_id\x18\x02 \x01(\x0c\x12\r\n\x05voter\x18\x03 \x01(\t\"\x8c\x02\n\x11\x45ventDepositClaim\x12\x13\n\x0b\x65vent_nonce\x18\x01 \x01(\x04\x12\x14\n\x0c\x65vent_height\x18\x02 \x01(\x04\x12\x16\n\x0e\x61ttestation_id\x18\x03 \x01(\x0c\x12\x17\n\x0f\x65thereum_sender\x18\x04 \x01(\t\x12\x17\n\x0f\x63osmos_receiver\x18\x05 \x01(\t\x12\x16\n\x0etoken_contract\x18\x06 \x01(\t\x12>\n\x06\x61mount\x18\x07 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12\x1c\n\x14orchestrator_address\x18\x08 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\t \x01(\t\"\xa2\x01\n\x12\x45ventWithdrawClaim\x12\x13\n\x0b\x65vent_nonce\x18\x01 \x01(\x04\x12\x14\n\x0c\x65vent_height\x18\x02 \x01(\x04\x12\x16\n\x0e\x61ttestation_id\x18\x03 \x01(\x0c\x12\x13\n\x0b\x62\x61tch_nonce\x18\x04 \x01(\x04\x12\x16\n\x0etoken_contract\x18\x05 \x01(\t\x12\x1c\n\x14orchestrator_address\x18\x06 \x01(\t\"\xd8\x01\n\x17\x45ventERC20DeployedClaim\x12\x13\n\x0b\x65vent_nonce\x18\x01 \x01(\x04\x12\x14\n\x0c\x65vent_height\x18\x02 \x01(\x04\x12\x16\n\x0e\x61ttestation_id\x18\x03 \x01(\x0c\x12\x14\n\x0c\x63osmos_denom\x18\x04 \x01(\t\x12\x16\n\x0etoken_contract\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0e\n\x06symbol\x18\x07 \x01(\t\x12\x10\n\x08\x64\x65\x63imals\x18\x08 \x01(\x04\x12\x1c\n\x14orchestrator_address\x18\t \x01(\t\"\xa9\x02\n\x16\x45ventValsetUpdateClaim\x12\x13\n\x0b\x65vent_nonce\x18\x01 \x01(\x04\x12\x14\n\x0c\x65vent_height\x18\x02 \x01(\x04\x12\x16\n\x0e\x61ttestation_id\x18\x03 \x01(\x0c\x12\x14\n\x0cvalset_nonce\x18\x04 \x01(\x04\x12;\n\x0evalset_members\x18\x05 \x03(\x0b\x32#.injective.peggy.v1.BridgeValidator\x12\x45\n\rreward_amount\x18\x06 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12\x14\n\x0creward_token\x18\x07 \x01(\t\x12\x1c\n\x14orchestrator_address\x18\x08 \x01(\t\".\n\x14\x45ventCancelSendToEth\x12\x16\n\x0eoutgoing_tx_id\x18\x01 \x01(\x04\"_\n\x1f\x45ventSubmitBadSignatureEvidence\x12\x19\n\x11\x62\x61\x64_eth_signature\x18\x01 \x01(\t\x12!\n\x19\x62\x61\x64_eth_signature_subject\x18\x02 \x01(\tBMZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,injective_dot_peggy_dot_v1_dot_attestation__pb2.DESCRIPTOR,injective_dot_peggy_dot_v1_dot_types__pb2.DESCRIPTOR,])




_EVENTATTESTATIONOBSERVED = _descriptor.Descriptor(
  name='EventAttestationObserved',
  full_name='injective.peggy.v1.EventAttestationObserved',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='attestation_type', full_name='injective.peggy.v1.EventAttestationObserved.attestation_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bridge_contract', full_name='injective.peggy.v1.EventAttestationObserved.bridge_contract', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bridge_chain_id', full_name='injective.peggy.v1.EventAttestationObserved.bridge_chain_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attestation_id', full_name='injective.peggy.v1.EventAttestationObserved.attestation_id', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nonce', full_name='injective.peggy.v1.EventAttestationObserved.nonce', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=148,
  serialized_end=320,
)


_EVENTBRIDGEWITHDRAWCANCELED = _descriptor.Descriptor(
  name='EventBridgeWithdrawCanceled',
  full_name='injective.peggy.v1.EventBridgeWithdrawCanceled',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bridge_contract', full_name='injective.peggy.v1.EventBridgeWithdrawCanceled.bridge_contract', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bridge_chain_id', full_name='injective.peggy.v1.EventBridgeWithdrawCanceled.bridge_chain_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=322,
  serialized_end=401,
)


_EVENTOUTGOINGBATCH = _descriptor.Descriptor(
  name='EventOutgoingBatch',
  full_name='injective.peggy.v1.EventOutgoingBatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='denom', full_name='injective.peggy.v1.EventOutgoingBatch.denom', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orchestrator_address', full_name='injective.peggy.v1.EventOutgoingBatch.orchestrator_address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batch_nonce', full_name='injective.peggy.v1.EventOutgoingBatch.batch_nonce', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batch_timeout', full_name='injective.peggy.v1.EventOutgoingBatch.batch_timeout', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batch_tx_ids', full_name='injective.peggy.v1.EventOutgoingBatch.batch_tx_ids', index=4,
      number=5, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=404,
  serialized_end=535,
)


_EVENTOUTGOINGBATCHCANCELED = _descriptor.Descriptor(
  name='EventOutgoingBatchCanceled',
  full_name='injective.peggy.v1.EventOutgoingBatchCanceled',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bridge_contract', full_name='injective.peggy.v1.EventOutgoingBatchCanceled.bridge_contract', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bridge_chain_id', full_name='injective.peggy.v1.EventOutgoingBatchCanceled.bridge_chain_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batch_id', full_name='injective.peggy.v1.EventOutgoingBatchCanceled.batch_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nonce', full_name='injective.peggy.v1.EventOutgoingBatchCanceled.nonce', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=537,
  serialized_end=648,
)


_EVENTVALSETUPDATEREQUEST = _descriptor.Descriptor(
  name='EventValsetUpdateRequest',
  full_name='injective.peggy.v1.EventValsetUpdateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='valset_nonce', full_name='injective.peggy.v1.EventValsetUpdateRequest.valset_nonce', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='valset_height', full_name='injective.peggy.v1.EventValsetUpdateRequest.valset_height', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='valset_members', full_name='injective.peggy.v1.EventValsetUpdateRequest.valset_members', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reward_amount', full_name='injective.peggy.v1.EventValsetUpdateRequest.reward_amount', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reward_token', full_name='injective.peggy.v1.EventValsetUpdateRequest.reward_token', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=651,
  serialized_end=876,
)


_EVENTSETORCHESTRATORADDRESSES = _descriptor.Descriptor(
  name='EventSetOrchestratorAddresses',
  full_name='injective.peggy.v1.EventSetOrchestratorAddresses',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='validator_address', full_name='injective.peggy.v1.EventSetOrchestratorAddresses.validator_address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orchestrator_address', full_name='injective.peggy.v1.EventSetOrchestratorAddresses.orchestrator_address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operator_eth_address', full_name='injective.peggy.v1.EventSetOrchestratorAddresses.operator_eth_address', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=878,
  serialized_end=996,
)


_EVENTVALSETCONFIRM = _descriptor.Descriptor(
  name='EventValsetConfirm',
  full_name='injective.peggy.v1.EventValsetConfirm',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='valset_nonce', full_name='injective.peggy.v1.EventValsetConfirm.valset_nonce', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orchestrator_address', full_name='injective.peggy.v1.EventValsetConfirm.orchestrator_address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=998,
  serialized_end=1070,
)


_EVENTSENDTOETH = _descriptor.Descriptor(
  name='EventSendToEth',
  full_name='injective.peggy.v1.EventSendToEth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='outgoing_tx_id', full_name='injective.peggy.v1.EventSendToEth.outgoing_tx_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.peggy.v1.EventSendToEth.sender', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='receiver', full_name='injective.peggy.v1.EventSendToEth.receiver', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='injective.peggy.v1.EventSendToEth.amount', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037\'github.com/cosmos/cosmos-sdk/types.Coin\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bridge_fee', full_name='injective.peggy.v1.EventSendToEth.bridge_fee', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037\'github.com/cosmos/cosmos-sdk/types.Coin\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1073,
  serialized_end=1281,
)


_EVENTCONFIRMBATCH = _descriptor.Descriptor(
  name='EventConfirmBatch',
  full_name='injective.peggy.v1.EventConfirmBatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='batch_nonce', full_name='injective.peggy.v1.EventConfirmBatch.batch_nonce', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orchestrator_address', full_name='injective.peggy.v1.EventConfirmBatch.orchestrator_address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1283,
  serialized_end=1353,
)


_EVENTATTESTATIONVOTE = _descriptor.Descriptor(
  name='EventAttestationVote',
  full_name='injective.peggy.v1.EventAttestationVote',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_nonce', full_name='injective.peggy.v1.EventAttestationVote.event_nonce', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attestation_id', full_name='injective.peggy.v1.EventAttestationVote.attestation_id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='voter', full_name='injective.peggy.v1.EventAttestationVote.voter', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1355,
  serialized_end=1437,
)


_EVENTDEPOSITCLAIM = _descriptor.Descriptor(
  name='EventDepositClaim',
  full_name='injective.peggy.v1.EventDepositClaim',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_nonce', full_name='injective.peggy.v1.EventDepositClaim.event_nonce', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_height', full_name='injective.peggy.v1.EventDepositClaim.event_height', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attestation_id', full_name='injective.peggy.v1.EventDepositClaim.attestation_id', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ethereum_sender', full_name='injective.peggy.v1.EventDepositClaim.ethereum_sender', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cosmos_receiver', full_name='injective.peggy.v1.EventDepositClaim.cosmos_receiver', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token_contract', full_name='injective.peggy.v1.EventDepositClaim.token_contract', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='injective.peggy.v1.EventDepositClaim.amount', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orchestrator_address', full_name='injective.peggy.v1.EventDepositClaim.orchestrator_address', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='injective.peggy.v1.EventDepositClaim.data', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1440,
  serialized_end=1708,
)


_EVENTWITHDRAWCLAIM = _descriptor.Descriptor(
  name='EventWithdrawClaim',
  full_name='injective.peggy.v1.EventWithdrawClaim',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_nonce', full_name='injective.peggy.v1.EventWithdrawClaim.event_nonce', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_height', full_name='injective.peggy.v1.EventWithdrawClaim.event_height', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attestation_id', full_name='injective.peggy.v1.EventWithdrawClaim.attestation_id', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batch_nonce', full_name='injective.peggy.v1.EventWithdrawClaim.batch_nonce', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token_contract', full_name='injective.peggy.v1.EventWithdrawClaim.token_contract', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orchestrator_address', full_name='injective.peggy.v1.EventWithdrawClaim.orchestrator_address', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1711,
  serialized_end=1873,
)


_EVENTERC20DEPLOYEDCLAIM = _descriptor.Descriptor(
  name='EventERC20DeployedClaim',
  full_name='injective.peggy.v1.EventERC20DeployedClaim',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_nonce', full_name='injective.peggy.v1.EventERC20DeployedClaim.event_nonce', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_height', full_name='injective.peggy.v1.EventERC20DeployedClaim.event_height', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attestation_id', full_name='injective.peggy.v1.EventERC20DeployedClaim.attestation_id', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cosmos_denom', full_name='injective.peggy.v1.EventERC20DeployedClaim.cosmos_denom', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token_contract', full_name='injective.peggy.v1.EventERC20DeployedClaim.token_contract', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='injective.peggy.v1.EventERC20DeployedClaim.name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='injective.peggy.v1.EventERC20DeployedClaim.symbol', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decimals', full_name='injective.peggy.v1.EventERC20DeployedClaim.decimals', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orchestrator_address', full_name='injective.peggy.v1.EventERC20DeployedClaim.orchestrator_address', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1876,
  serialized_end=2092,
)


_EVENTVALSETUPDATECLAIM = _descriptor.Descriptor(
  name='EventValsetUpdateClaim',
  full_name='injective.peggy.v1.EventValsetUpdateClaim',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_nonce', full_name='injective.peggy.v1.EventValsetUpdateClaim.event_nonce', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_height', full_name='injective.peggy.v1.EventValsetUpdateClaim.event_height', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attestation_id', full_name='injective.peggy.v1.EventValsetUpdateClaim.attestation_id', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='valset_nonce', full_name='injective.peggy.v1.EventValsetUpdateClaim.valset_nonce', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='valset_members', full_name='injective.peggy.v1.EventValsetUpdateClaim.valset_members', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reward_amount', full_name='injective.peggy.v1.EventValsetUpdateClaim.reward_amount', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reward_token', full_name='injective.peggy.v1.EventValsetUpdateClaim.reward_token', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orchestrator_address', full_name='injective.peggy.v1.EventValsetUpdateClaim.orchestrator_address', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2095,
  serialized_end=2392,
)


_EVENTCANCELSENDTOETH = _descriptor.Descriptor(
  name='EventCancelSendToEth',
  full_name='injective.peggy.v1.EventCancelSendToEth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='outgoing_tx_id', full_name='injective.peggy.v1.EventCancelSendToEth.outgoing_tx_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2394,
  serialized_end=2440,
)


_EVENTSUBMITBADSIGNATUREEVIDENCE = _descriptor.Descriptor(
  name='EventSubmitBadSignatureEvidence',
  full_name='injective.peggy.v1.EventSubmitBadSignatureEvidence',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bad_eth_signature', full_name='injective.peggy.v1.EventSubmitBadSignatureEvidence.bad_eth_signature', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bad_eth_signature_subject', full_name='injective.peggy.v1.EventSubmitBadSignatureEvidence.bad_eth_signature_subject', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2442,
  serialized_end=2537,
)

_EVENTATTESTATIONOBSERVED.fields_by_name['attestation_type'].enum_type = injective_dot_peggy_dot_v1_dot_attestation__pb2._CLAIMTYPE
_EVENTVALSETUPDATEREQUEST.fields_by_name['valset_members'].message_type = injective_dot_peggy_dot_v1_dot_types__pb2._BRIDGEVALIDATOR
_EVENTVALSETUPDATECLAIM.fields_by_name['valset_members'].message_type = injective_dot_peggy_dot_v1_dot_types__pb2._BRIDGEVALIDATOR
DESCRIPTOR.message_types_by_name['EventAttestationObserved'] = _EVENTATTESTATIONOBSERVED
DESCRIPTOR.message_types_by_name['EventBridgeWithdrawCanceled'] = _EVENTBRIDGEWITHDRAWCANCELED
DESCRIPTOR.message_types_by_name['EventOutgoingBatch'] = _EVENTOUTGOINGBATCH
DESCRIPTOR.message_types_by_name['EventOutgoingBatchCanceled'] = _EVENTOUTGOINGBATCHCANCELED
DESCRIPTOR.message_types_by_name['EventValsetUpdateRequest'] = _EVENTVALSETUPDATEREQUEST
DESCRIPTOR.message_types_by_name['EventSetOrchestratorAddresses'] = _EVENTSETORCHESTRATORADDRESSES
DESCRIPTOR.message_types_by_name['EventValsetConfirm'] = _EVENTVALSETCONFIRM
DESCRIPTOR.message_types_by_name['EventSendToEth'] = _EVENTSENDTOETH
DESCRIPTOR.message_types_by_name['EventConfirmBatch'] = _EVENTCONFIRMBATCH
DESCRIPTOR.message_types_by_name['EventAttestationVote'] = _EVENTATTESTATIONVOTE
DESCRIPTOR.message_types_by_name['EventDepositClaim'] = _EVENTDEPOSITCLAIM
DESCRIPTOR.message_types_by_name['EventWithdrawClaim'] = _EVENTWITHDRAWCLAIM
DESCRIPTOR.message_types_by_name['EventERC20DeployedClaim'] = _EVENTERC20DEPLOYEDCLAIM
DESCRIPTOR.message_types_by_name['EventValsetUpdateClaim'] = _EVENTVALSETUPDATECLAIM
DESCRIPTOR.message_types_by_name['EventCancelSendToEth'] = _EVENTCANCELSENDTOETH
DESCRIPTOR.message_types_by_name['EventSubmitBadSignatureEvidence'] = _EVENTSUBMITBADSIGNATUREEVIDENCE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EventAttestationObserved = _reflection.GeneratedProtocolMessageType('EventAttestationObserved', (_message.Message,), {
  'DESCRIPTOR' : _EVENTATTESTATIONOBSERVED,
  '__module__' : 'injective.peggy.v1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.EventAttestationObserved)
  })
_sym_db.RegisterMessage(EventAttestationObserved)

EventBridgeWithdrawCanceled = _reflection.GeneratedProtocolMessageType('EventBridgeWithdrawCanceled', (_message.Message,), {
  'DESCRIPTOR' : _EVENTBRIDGEWITHDRAWCANCELED,
  '__module__' : 'injective.peggy.v1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.EventBridgeWithdrawCanceled)
  })
_sym_db.RegisterMessage(EventBridgeWithdrawCanceled)

EventOutgoingBatch = _reflection.GeneratedProtocolMessageType('EventOutgoingBatch', (_message.Message,), {
  'DESCRIPTOR' : _EVENTOUTGOINGBATCH,
  '__module__' : 'injective.peggy.v1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.EventOutgoingBatch)
  })
_sym_db.RegisterMessage(EventOutgoingBatch)

EventOutgoingBatchCanceled = _reflection.GeneratedProtocolMessageType('EventOutgoingBatchCanceled', (_message.Message,), {
  'DESCRIPTOR' : _EVENTOUTGOINGBATCHCANCELED,
  '__module__' : 'injective.peggy.v1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.EventOutgoingBatchCanceled)
  })
_sym_db.RegisterMessage(EventOutgoingBatchCanceled)

EventValsetUpdateRequest = _reflection.GeneratedProtocolMessageType('EventValsetUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _EVENTVALSETUPDATEREQUEST,
  '__module__' : 'injective.peggy.v1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.EventValsetUpdateRequest)
  })
_sym_db.RegisterMessage(EventValsetUpdateRequest)

EventSetOrchestratorAddresses = _reflection.GeneratedProtocolMessageType('EventSetOrchestratorAddresses', (_message.Message,), {
  'DESCRIPTOR' : _EVENTSETORCHESTRATORADDRESSES,
  '__module__' : 'injective.peggy.v1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.EventSetOrchestratorAddresses)
  })
_sym_db.RegisterMessage(EventSetOrchestratorAddresses)

EventValsetConfirm = _reflection.GeneratedProtocolMessageType('EventValsetConfirm', (_message.Message,), {
  'DESCRIPTOR' : _EVENTVALSETCONFIRM,
  '__module__' : 'injective.peggy.v1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.EventValsetConfirm)
  })
_sym_db.RegisterMessage(EventValsetConfirm)

EventSendToEth = _reflection.GeneratedProtocolMessageType('EventSendToEth', (_message.Message,), {
  'DESCRIPTOR' : _EVENTSENDTOETH,
  '__module__' : 'injective.peggy.v1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.EventSendToEth)
  })
_sym_db.RegisterMessage(EventSendToEth)

EventConfirmBatch = _reflection.GeneratedProtocolMessageType('EventConfirmBatch', (_message.Message,), {
  'DESCRIPTOR' : _EVENTCONFIRMBATCH,
  '__module__' : 'injective.peggy.v1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.EventConfirmBatch)
  })
_sym_db.RegisterMessage(EventConfirmBatch)

EventAttestationVote = _reflection.GeneratedProtocolMessageType('EventAttestationVote', (_message.Message,), {
  'DESCRIPTOR' : _EVENTATTESTATIONVOTE,
  '__module__' : 'injective.peggy.v1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.EventAttestationVote)
  })
_sym_db.RegisterMessage(EventAttestationVote)

EventDepositClaim = _reflection.GeneratedProtocolMessageType('EventDepositClaim', (_message.Message,), {
  'DESCRIPTOR' : _EVENTDEPOSITCLAIM,
  '__module__' : 'injective.peggy.v1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.EventDepositClaim)
  })
_sym_db.RegisterMessage(EventDepositClaim)

EventWithdrawClaim = _reflection.GeneratedProtocolMessageType('EventWithdrawClaim', (_message.Message,), {
  'DESCRIPTOR' : _EVENTWITHDRAWCLAIM,
  '__module__' : 'injective.peggy.v1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.EventWithdrawClaim)
  })
_sym_db.RegisterMessage(EventWithdrawClaim)

EventERC20DeployedClaim = _reflection.GeneratedProtocolMessageType('EventERC20DeployedClaim', (_message.Message,), {
  'DESCRIPTOR' : _EVENTERC20DEPLOYEDCLAIM,
  '__module__' : 'injective.peggy.v1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.EventERC20DeployedClaim)
  })
_sym_db.RegisterMessage(EventERC20DeployedClaim)

EventValsetUpdateClaim = _reflection.GeneratedProtocolMessageType('EventValsetUpdateClaim', (_message.Message,), {
  'DESCRIPTOR' : _EVENTVALSETUPDATECLAIM,
  '__module__' : 'injective.peggy.v1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.EventValsetUpdateClaim)
  })
_sym_db.RegisterMessage(EventValsetUpdateClaim)

EventCancelSendToEth = _reflection.GeneratedProtocolMessageType('EventCancelSendToEth', (_message.Message,), {
  'DESCRIPTOR' : _EVENTCANCELSENDTOETH,
  '__module__' : 'injective.peggy.v1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.EventCancelSendToEth)
  })
_sym_db.RegisterMessage(EventCancelSendToEth)

EventSubmitBadSignatureEvidence = _reflection.GeneratedProtocolMessageType('EventSubmitBadSignatureEvidence', (_message.Message,), {
  'DESCRIPTOR' : _EVENTSUBMITBADSIGNATUREEVIDENCE,
  '__module__' : 'injective.peggy.v1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.EventSubmitBadSignatureEvidence)
  })
_sym_db.RegisterMessage(EventSubmitBadSignatureEvidence)


DESCRIPTOR._options = None
_EVENTVALSETUPDATEREQUEST.fields_by_name['reward_amount']._options = None
_EVENTSENDTOETH.fields_by_name['amount']._options = None
_EVENTSENDTOETH.fields_by_name['bridge_fee']._options = None
_EVENTDEPOSITCLAIM.fields_by_name['amount']._options = None
_EVENTVALSETUPDATECLAIM.fields_by_name['reward_amount']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tendermint/p2p/conn.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from tendermint.crypto import keys_pb2 as tendermint_dot_crypto_dot_keys__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tendermint/p2p/conn.proto',
  package='tendermint.p2p',
  syntax='proto3',
  serialized_options=b'Z5github.com/tendermint/tendermint/proto/tendermint/p2p',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x19tendermint/p2p/conn.proto\x12\x0etendermint.p2p\x1a\x14gogoproto/gogo.proto\x1a\x1ctendermint/crypto/keys.proto\"\x0c\n\nPacketPing\"\x0c\n\nPacketPong\"R\n\tPacketMsg\x12!\n\nchannel_id\x18\x01 \x01(\x05\x42\r\xe2\xde\x1f\tChannelID\x12\x14\n\x03\x65of\x18\x02 \x01(\x08\x42\x07\xe2\xde\x1f\x03\x45OF\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\"\xa6\x01\n\x06Packet\x12\x31\n\x0bpacket_ping\x18\x01 \x01(\x0b\x32\x1a.tendermint.p2p.PacketPingH\x00\x12\x31\n\x0bpacket_pong\x18\x02 \x01(\x0b\x32\x1a.tendermint.p2p.PacketPongH\x00\x12/\n\npacket_msg\x18\x03 \x01(\x0b\x32\x19.tendermint.p2p.PacketMsgH\x00\x42\x05\n\x03sum\"R\n\x0e\x41uthSigMessage\x12\x33\n\x07pub_key\x18\x01 \x01(\x0b\x32\x1c.tendermint.crypto.PublicKeyB\x04\xc8\xde\x1f\x00\x12\x0b\n\x03sig\x18\x02 \x01(\x0c\x42\x37Z5github.com/tendermint/tendermint/proto/tendermint/p2pb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,tendermint_dot_crypto_dot_keys__pb2.DESCRIPTOR,])




_PACKETPING = _descriptor.Descriptor(
  name='PacketPing',
  full_name='tendermint.p2p.PacketPing',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=97,
  serialized_end=109,
)


_PACKETPONG = _descriptor.Descriptor(
  name='PacketPong',
  full_name='tendermint.p2p.PacketPong',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=111,
  serialized_end=123,
)


_PACKETMSG = _descriptor.Descriptor(
  name='PacketMsg',
  full_name='tendermint.p2p.PacketMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel_id', full_name='tendermint.p2p.PacketMsg.channel_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\tChannelID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eof', full_name='tendermint.p2p.PacketMsg.eof', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\003EOF', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='tendermint.p2p.PacketMsg.data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=125,
  serialized_end=207,
)


_PACKET = _descriptor.Descriptor(
  name='Packet',
  full_name='tendermint.p2p.Packet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='packet_ping', full_name='tendermint.p2p.Packet.packet_ping', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packet_pong', full_name='tendermint.p2p.Packet.packet_pong', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packet_msg', full_name='tendermint.p2p.Packet.packet_msg', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='sum', full_name='tendermint.p2p.Packet.sum',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=210,
  serialized_end=376,
)


_AUTHSIGMESSAGE = _descriptor.Descriptor(
  name='AuthSigMessage',
  full_name='tendermint.p2p.AuthSigMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pub_key', full_name='tendermint.p2p.AuthSigMessage.pub_key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sig', full_name='tendermint.p2p.AuthSigMessage.sig', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=378,
  serialized_end=460,
)

_PACKET.fields_by_name['packet_ping'].message_type = _PACKETPING
_PACKET.fields_by_name['packet_pong'].message_type = _PACKETPONG
_PACKET.fields_by_name['packet_msg'].message_type = _PACKETMSG
_PACKET.oneofs_by_name['sum'].fields.append(
  _PACKET.fields_by_name['packet_ping'])
_PACKET.fields_by_name['packet_ping'].containing_oneof = _PACKET.oneofs_by_name['sum']
_PACKET.oneofs_by_name['sum'].fields.append(
  _PACKET.fields_by_name['packet_pong'])
_PACKET.fields_by_name['packet_pong'].containing_oneof = _PACKET.oneofs_by_name['sum']
_PACKET.oneofs_by_name['sum'].fields.append(
  _PACKET.fields_by_name['packet_msg'])
_PACKET.fields_by_name['packet_msg'].containing_oneof = _PACKET.oneofs_by_name['sum']
_AUTHSIGMESSAGE.fields_by_name['pub_key'].message_type = tendermint_dot_crypto_dot_keys__pb2._PUBLICKEY
DESCRIPTOR.message_types_by_name['PacketPing'] = _PACKETPING
DESCRIPTOR.message_types_by_name['PacketPong'] = _PACKETPONG
DESCRIPTOR.message_types_by_name['PacketMsg'] = _PACKETMSG
DESCRIPTOR.message_types_by_name['Packet'] = _PACKET
DESCRIPTOR.message_types_by_name['AuthSigMessage'] = _AUTHSIGMESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PacketPing = _reflection.GeneratedProtocolMessageType('PacketPing', (_message.Message,), {
  'DESCRIPTOR' : _PACKETPING,
  '__module__' : 'tendermint.p2p.conn_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.p2p.PacketPing)
  })
_sym_db.RegisterMessage(PacketPing)

PacketPong = _reflection.GeneratedProtocolMessageType('PacketPong', (_message.Message,), {
  'DESCRIPTOR' : _PACKETPONG,
  '__module__' : 'tendermint.p2p.conn_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.p2p.PacketPong)
  })
_sym_db.RegisterMessage(PacketPong)

PacketMsg = _reflection.GeneratedProtocolMessageType('PacketMsg', (_message.Message,), {
  'DESCRIPTOR' : _PACKETMSG,
  '__module__' : 'tendermint.p2p.conn_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.p2p.PacketMsg)
  })
_sym_db.RegisterMessage(PacketMsg)

Packet = _reflection.GeneratedProtocolMessageType('Packet', (_message.Message,), {
  'DESCRIPTOR' : _PACKET,
  '__module__' : 'tendermint.p2p.conn_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.p2p.Packet)
  })
_sym_db.RegisterMessage(Packet)

AuthSigMessage = _reflection.GeneratedProtocolMessageType('AuthSigMessage', (_message.Message,), {
  'DESCRIPTOR' : _AUTHSIGMESSAGE,
  '__module__' : 'tendermint.p2p.conn_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.p2p.AuthSigMessage)
  })
_sym_db.RegisterMessage(AuthSigMessage)


DESCRIPTOR._options = None
_PACKETMSG.fields_by_name['channel_id']._options = None
_PACKETMSG.fields_by_name['eof']._options = None
_AUTHSIGMESSAGE.fields_by_name['pub_key']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/insurance/v1beta1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from injective.insurance.v1beta1 import insurance_pb2 as injective_dot_insurance_dot_v1beta1_dot_insurance__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from injective.insurance.v1beta1 import genesis_pb2 as injective_dot_insurance_dot_v1beta1_dot_genesis__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='injective/insurance/v1beta1/query.proto',
  package='injective.insurance.v1beta1',
  syntax='proto3',
  serialized_options=b'ZOgithub.com/InjectiveLabs/injective-core/injective-chain/modules/insurance/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\'injective/insurance/v1beta1/query.proto\x12\x1binjective.insurance.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a+injective/insurance/v1beta1/insurance.proto\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a)injective/insurance/v1beta1/genesis.proto\"\x1d\n\x1bQueryInsuranceParamsRequest\"Y\n\x1cQueryInsuranceParamsResponse\x12\x39\n\x06params\x18\x01 \x01(\x0b\x32#.injective.insurance.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\".\n\x19QueryInsuranceFundRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\"V\n\x1aQueryInsuranceFundResponse\x12\x38\n\x04\x66und\x18\x01 \x01(\x0b\x32*.injective.insurance.v1beta1.InsuranceFund\"\x1c\n\x1aQueryInsuranceFundsRequest\"^\n\x1bQueryInsuranceFundsResponse\x12?\n\x05\x66unds\x18\x01 \x03(\x0b\x32*.injective.insurance.v1beta1.InsuranceFundB\x04\xc8\xde\x1f\x00\"E\n QueryEstimatedRedemptionsRequest\x12\x10\n\x08marketId\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\"T\n!QueryEstimatedRedemptionsResponse\x12/\n\x06\x61mount\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"C\n\x1eQueryPendingRedemptionsRequest\x12\x10\n\x08marketId\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\"R\n\x1fQueryPendingRedemptionsResponse\x12/\n\x06\x61mount\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"\x19\n\x17QueryModuleStateRequest\"T\n\x18QueryModuleStateResponse\x12\x38\n\x05state\x18\x01 \x01(\x0b\x32).injective.insurance.v1beta1.GenesisState2\x96\t\n\x05Query\x12\xb3\x01\n\x0fInsuranceParams\x12\x38.injective.insurance.v1beta1.QueryInsuranceParamsRequest\x1a\x39.injective.insurance.v1beta1.QueryInsuranceParamsResponse\"+\x82\xd3\xe4\x93\x02%\x12#/injective/insurance/v1beta1/params\x12\xc1\x01\n\rInsuranceFund\x12\x36.injective.insurance.v1beta1.QueryInsuranceFundRequest\x1a\x37.injective.insurance.v1beta1.QueryInsuranceFundResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/injective/insurance/v1beta1/insurance_fund/{market_id}\x12\xb9\x01\n\x0eInsuranceFunds\x12\x37.injective.insurance.v1beta1.QueryInsuranceFundsRequest\x1a\x38.injective.insurance.v1beta1.QueryInsuranceFundsResponse\"4\x82\xd3\xe4\x93\x02.\x12,/injective/insurance/v1beta1/insurance_funds\x12\xd1\x01\n\x14\x45stimatedRedemptions\x12=.injective.insurance.v1beta1.QueryEstimatedRedemptionsRequest\x1a>.injective.insurance.v1beta1.QueryEstimatedRedemptionsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/injective/insurance/v1beta1/estimated_redemptions\x12\xc9\x01\n\x12PendingRedemptions\x12;.injective.insurance.v1beta1.QueryPendingRedemptionsRequest\x1a<.injective.insurance.v1beta1.QueryPendingRedemptionsResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/injective/insurance/v1beta1/pending_redemptions\x12\xb6\x01\n\x14InsuranceModuleState\x12\x34.injective.insurance.v1beta1.QueryModuleStateRequest\x1a\x35.injective.insurance.v1beta1.QueryModuleStateResponse\"1\x82\xd3\xe4\x93\x02+\x12)/injective/insurance/v1beta1/module_stateBQZOgithub.com/InjectiveLabs/injective-core/injective-chain/modules/insurance/typesb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,injective_dot_insurance_dot_v1beta1_dot_insurance__pb2.DESCRIPTOR,gogoproto_dot_gogo__pb2.DESCRIPTOR,cosmos_dot_base_dot_v1beta1_dot_coin__pb2.DESCRIPTOR,injective_dot_insurance_dot_v1beta1_dot_genesis__pb2.DESCRIPTOR,])




_QUERYINSURANCEPARAMSREQUEST = _descriptor.Descriptor(
  name='QueryInsuranceParamsRequest',
  full_name='injective.insurance.v1beta1.QueryInsuranceParamsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=244,
  serialized_end=273,
)


_QUERYINSURANCEPARAMSRESPONSE = _descriptor.Descriptor(
  name='QueryInsuranceParamsResponse',
  full_name='injective.insurance.v1beta1.QueryInsuranceParamsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='params', full_name='injective.insurance.v1beta1.QueryInsuranceParamsResponse.params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=275,
  serialized_end=364,
)


_QUERYINSURANCEFUNDREQUEST = _descriptor.Descriptor(
  name='QueryInsuranceFundRequest',
  full_name='injective.insurance.v1beta1.QueryInsuranceFundRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.insurance.v1beta1.QueryInsuranceFundRequest.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=366,
  serialized_end=412,
)


_QUERYINSURANCEFUNDRESPONSE = _descriptor.Descriptor(
  name='QueryInsuranceFundResponse',
  full_name='injective.insurance.v1beta1.QueryInsuranceFundResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fund', full_name='injective.insurance.v1beta1.QueryInsuranceFundResponse.fund', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=414,
  serialized_end=500,
)


_QUERYINSURANCEFUNDSREQUEST = _descriptor.Descriptor(
  name='QueryInsuranceFundsRequest',
  full_name='injective.insurance.v1beta1.QueryInsuranceFundsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=502,
  serialized_end=530,
)


_QUERYINSURANCEFUNDSRESPONSE = _descriptor.Descriptor(
  name='QueryInsuranceFundsResponse',
  full_name='injective.insurance.v1beta1.QueryInsuranceFundsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='funds', full_name='injective.insurance.v1beta1.QueryInsuranceFundsResponse.funds', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=532,
  serialized_end=626,
)


_QUERYESTIMATEDREDEMPTIONSREQUEST = _descriptor.Descriptor(
  name='QueryEstimatedRedemptionsRequest',
  full_name='injective.insurance.v1beta1.QueryEstimatedRedemptionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='marketId', full_name='injective.insurance.v1beta1.QueryEstimatedRedemptionsRequest.marketId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='address', full_name='injective.insurance.v1beta1.QueryEstimatedRedemptionsRequest.address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=628,
  serialized_end=697,
)


_QUERYESTIMATEDREDEMPTIONSRESPONSE = _descriptor.Descriptor(
  name='QueryEstimatedRedemptionsResponse',
  full_name='injective.insurance.v1beta1.QueryEstimatedRedemptionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='amount', full_name='injective.insurance.v1beta1.QueryEstimatedRedemptionsResponse.amount', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=699,
  serialized_end=783,
)


_QUERYPENDINGREDEMPTIONSREQUEST = _descriptor.Descriptor(
  name='QueryPendingRedemptionsRequest',
  full_name='injective.insurance.v1beta1.QueryPendingRedemptionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='marketId', full_name='injective.insurance.v1beta1.QueryPendingRedemptionsRequest.marketId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='address', full_name='injective.insurance.v1beta1.QueryPendingRedemptionsRequest.address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=785,
  serialized_end=852,
)


_QUERYPENDINGREDEMPTIONSRESPONSE = _descriptor.Descriptor(
  name='QueryPendingRedemptionsResponse',
  full_name='injective.insurance.v1beta1.QueryPendingRedemptionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='amount', full_name='injective.insurance.v1beta1.QueryPendingRedemptionsResponse.amount', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=854,
  serialized_end=936,
)


_QUERYMODULESTATEREQUEST = _descriptor.Descriptor(
  name='QueryModuleStateRequest',
  full_name='injective.insurance.v1beta1.QueryModuleStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=938,
  serialized_end=963,
)


_QUERYMODULESTATERESPONSE = _descriptor.Descriptor(
  name='QueryModuleStateResponse',
  full_name='injective.insurance.v1beta1.QueryModuleStateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='injective.insurance.v1beta1.QueryModuleStateResponse.state', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=965,
  serialized_end=1049,
)

_QUERYINSURANCEPARAMSRESPONSE.fields_by_name['params'].message_type = injective_dot_insurance_dot_v1beta1_dot_insurance__pb2._PARAMS
_QUERYINSURANCEFUNDRESPONSE.fields_by_name['fund'].message_type = injective_dot_insurance_dot_v1beta1_dot_insurance__pb2._INSURANCEFUND
_QUERYINSURANCEFUNDSRESPONSE.fields_by_name['funds'].message_type = injective_dot_insurance_dot_v1beta1_dot_insurance__pb2._INSURANCEFUND
_QUERYESTIMATEDREDEMPTIONSRESPONSE.fields_by_name['amount'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_QUERYPENDINGREDEMPTIONSRESPONSE.fields_by_name['amount'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_QUERYMODULESTATERESPONSE.fields_by_name['state'].message_type = injective_dot_insurance_dot_v1beta1_dot_genesis__pb2._GENESISSTATE
DESCRIPTOR.message_types_by_name['QueryInsuranceParamsRequest'] = _QUERYINSURANCEPARAMSREQUEST
DESCRIPTOR.message_types_by_name['QueryInsuranceParamsResponse'] = _QUERYINSURANCEPARAMSRESPONSE
DESCRIPTOR.message_types_by_name['QueryInsuranceFundRequest'] = _QUERYINSURANCEFUNDREQUEST
DESCRIPTOR.message_types_by_name['QueryInsuranceFundResponse'] = _QUERYINSURANCEFUNDRESPONSE
DESCRIPTOR.message_types_by_name['QueryInsuranceFundsRequest'] = _QUERYINSURANCEFUNDSREQUEST
DESCRIPTOR.message_types_by_name['QueryInsuranceFundsResponse'] = _QUERYINSURANCEFUNDSRESPONSE
DESCRIPTOR.message_types_by_name['QueryEstimatedRedemptionsRequest'] = _QUERYESTIMATEDREDEMPTIONSREQUEST
DESCRIPTOR.message_types_by_name['QueryEstimatedRedemptionsResponse'] = _QUERYESTIMATEDREDEMPTIONSRESPONSE
DESCRIPTOR.message_types_by_name['QueryPendingRedemptionsRequest'] = _QUERYPENDINGREDEMPTIONSREQUEST
DESCRIPTOR.message_types_by_name['QueryPendingRedemptionsResponse'] = _QUERYPENDINGREDEMPTIONSRESPONSE
DESCRIPTOR.message_types_by_name['QueryModuleStateRequest'] = _QUERYMODULESTATEREQUEST
DESCRIPTOR.message_types_by_name['QueryModuleStateResponse'] = _QUERYMODULESTATERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

QueryInsuranceParamsRequest = _reflection.GeneratedProtocolMessageType('QueryInsuranceParamsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYINSURANCEPARAMSREQUEST,
  '__module__' : 'injective.insurance.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.insurance.v1beta1.QueryInsuranceParamsRequest)
  })
_sym_db.RegisterMessage(QueryInsuranceParamsRequest)

QueryInsuranceParamsResponse = _reflection.GeneratedProtocolMessageType('QueryInsuranceParamsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYINSURANCEPARAMSRESPONSE,
  '__module__' : 'injective.insurance.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.insurance.v1beta1.QueryInsuranceParamsResponse)
  })
_sym_db.RegisterMessage(QueryInsuranceParamsResponse)

QueryInsuranceFundRequest = _reflection.GeneratedProtocolMessageType('QueryInsuranceFundRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYINSURANCEFUNDREQUEST,
  '__module__' : 'injective.insurance.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.insurance.v1beta1.QueryInsuranceFundRequest)
  })
_sym_db.RegisterMessage(QueryInsuranceFundRequest)

QueryInsuranceFundResponse = _reflection.GeneratedProtocolMessageType('QueryInsuranceFundResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYINSURANCEFUNDRESPONSE,
  '__module__' : 'injective.insurance.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.insurance.v1beta1.QueryInsuranceFundResponse)
  })
_sym_db.RegisterMessage(QueryInsuranceFundResponse)

QueryInsuranceFundsRequest = _reflection.GeneratedProtocolMessageType('QueryInsuranceFundsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYINSURANCEFUNDSREQUEST,
  '__module__' : 'injective.insurance.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.insurance.v1beta1.QueryInsuranceFundsRequest)
  })
_sym_db.RegisterMessage(QueryInsuranceFundsRequest)

QueryInsuranceFundsResponse = _reflection.GeneratedProtocolMessageType('QueryInsuranceFundsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYINSURANCEFUNDSRESPONSE,
  '__module__' : 'injective.insurance.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.insurance.v1beta1.QueryInsuranceFundsResponse)
  })
_sym_db.RegisterMessage(QueryInsuranceFundsResponse)

QueryEstimatedRedemptionsRequest = _reflection.GeneratedProtocolMessageType('QueryEstimatedRedemptionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYESTIMATEDREDEMPTIONSREQUEST,
  '__module__' : 'injective.insurance.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.insurance.v1beta1.QueryEstimatedRedemptionsRequest)
  })
_sym_db.RegisterMessage(QueryEstimatedRedemptionsRequest)

QueryEstimatedRedemptionsResponse = _reflection.GeneratedProtocolMessageType('QueryEstimatedRedemptionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYESTIMATEDREDEMPTIONSRESPONSE,
  '__module__' : 'injective.insurance.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.insurance.v1beta1.QueryEstimatedRedemptionsResponse)
  })
_sym_db.RegisterMessage(QueryEstimatedRedemptionsResponse)

QueryPendingRedemptionsRequest = _reflection.GeneratedProtocolMessageType('QueryPendingRedemptionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPENDINGREDEMPTIONSREQUEST,
  '__module__' : 'injective.insurance.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.insurance.v1beta1.QueryPendingRedemptionsRequest)
  })
_sym_db.RegisterMessage(QueryPendingRedemptionsRequest)

QueryPendingRedemptionsResponse = _reflection.GeneratedProtocolMessageType('QueryPendingRedemptionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPENDINGREDEMPTIONSRESPONSE,
  '__module__' : 'injective.insurance.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.insurance.v1beta1.QueryPendingRedemptionsResponse)
  })
_sym_db.RegisterMessage(QueryPendingRedemptionsResponse)

QueryModuleStateRequest = _reflection.GeneratedProtocolMessageType('QueryModuleStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYMODULESTATEREQUEST,
  '__module__' : 'injective.insurance.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.insurance.v1beta1.QueryModuleStateRequest)
  })
_sym_db.RegisterMessage(QueryModuleStateRequest)

QueryModuleStateResponse = _reflection.GeneratedProtocolMessageType('QueryModuleStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYMODULESTATERESPONSE,
  '__module__' : 'injective.insurance.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.insurance.v1beta1.QueryModuleStateResponse)
  })
_sym_db.RegisterMessage(QueryModuleStateResponse)


DESCRIPTOR._options = None
_QUERYINSURANCEPARAMSRESPONSE.fields_by_name['params']._options = None
_QUERYINSURANCEFUNDSRESPONSE.fields_by_name['funds']._options = None
_QUERYESTIMATEDREDEMPTIONSRESPONSE.fields_by_name['amount']._options = None
_QUERYPENDINGREDEMPTIONSRESPONSE.fields_by_name['amount']._options = None

_QUERY = _descriptor.ServiceDescriptor(
  name='Query',
  full_name='injective.insurance.v1beta1.Query',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1052,
  serialized_end=2226,
  methods=[
  _descriptor.MethodDescriptor(
    name='InsuranceParams',
    full_name='injective.insurance.v1beta1.Query.InsuranceParams',
    index=0,
    containing_service=None,
    input_type=_QUERYINSURANCEPARAMSREQUEST,
    output_type=_QUERYINSURANCEPARAMSRESPONSE,
    serialized_options=b'\202\323\344\223\002%\022#/injective/insurance/v1beta1/params',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='InsuranceFund',
    full_name='injective.insurance.v1beta1.Query.InsuranceFund',
    index=1,
    containing_service=None,
    input_type=_QUERYINSURANCEFUNDREQUEST,
    output_type=_QUERYINSURANCEFUNDRESPONSE,
    serialized_options=b'\202\323\344\223\0029\0227/injective/insurance/v1beta1/insurance_fund/{market_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='InsuranceFunds',
    full_name='injective.insurance.v1beta1.Query.InsuranceFunds',
    index=2,
    containing_service=None,
    input_type=_QUERYINSURANCEFUNDSREQUEST,
    output_type=_QUERYINSURANCEFUNDSRESPONSE,
    serialized_options=b'\202\323\344\223\002.\022,/injective/insurance/v1beta1/insurance_funds',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EstimatedRedemptions',
    full_name='injective.insurance.v1beta1.Query.EstimatedRedemptions',
    index=3,
    containing_service=None,
    input_type=_QUERYESTIMATEDREDEMPTIONSREQUEST,
    output_type=_QUERYESTIMATEDREDEMPTIONSRESPONSE,
    serialized_options=b'\202\323\344\223\0024\0222/injective/insurance/v1beta1/estimated_redemptions',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PendingRedemptions',
    full_name='injective.insurance.v1beta1.Query.PendingRedemptions',
    index=4,
    containing_service=None,
    input_type=_QUERYPENDINGREDEMPTIONSREQUEST,
    output_type=_QUERYPENDINGREDEMPTIONSRESPONSE,
    serialized_options=b'\202\323\344\223\0022\0220/injective/insurance/v1beta1/pending_redemptions',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='InsuranceModuleState',
    full_name='injective.insurance.v1beta1.Query.InsuranceModuleState',
    index=5,
    containing_service=None,
    input_type=_QUERYMODULESTATEREQUEST,
    output_type=_QUERYMODULESTATERESPONSE,
    serialized_options=b'\202\323\344\223\002+\022)/injective/insurance/v1beta1/module_state',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_QUERY)

DESCRIPTOR.services_by_name['Query'] = _QUERY

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tendermint/mempool/types.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='tendermint/mempool/types.proto',
  package='tendermint.mempool',
  syntax='proto3',
  serialized_options=b'Z9github.com/tendermint/tendermint/proto/tendermint/mempool',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1etendermint/mempool/types.proto\x12\x12tendermint.mempool\"\x12\n\x03Txs\x12\x0b\n\x03txs\x18\x01 \x03(\x0c\"8\n\x07Message\x12&\n\x03txs\x18\x01 \x01(\x0b\x32\x17.tendermint.mempool.TxsH\x00\x42\x05\n\x03sumB;Z9github.com/tendermint/tendermint/proto/tendermint/mempoolb\x06proto3'
)




_TXS = _descriptor.Descriptor(
  name='Txs',
  full_name='tendermint.mempool.Txs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='txs', full_name='tendermint.mempool.Txs.txs', index=0,
      number=1, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=54,
  serialized_end=72,
)


_MESSAGE = _descriptor.Descriptor(
  name='Message',
  full_name='tendermint.mempool.Message',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='txs', full_name='tendermint.mempool.Message.txs', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='sum', full_name='tendermint.mempool.Message.sum',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=74,
  serialized_end=130,
)

_MESSAGE.fields_by_name['txs'].message_type = _TXS
_MESSAGE.oneofs_by_name['sum'].fields.append(
  _MESSAGE.fields_by_name['txs'])
_MESSAGE.fields_by_name['txs'].containing_oneof = _MESSAGE.oneofs_by_name['sum']
DESCRIPTOR.message_types_by_name['Txs'] = _TXS
DESCRIPTOR.message_types_by_name['Message'] = _MESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Txs = _reflection.GeneratedProtocolMessageType('Txs', (_message.Message,), {
  'DESCRIPTOR' : _TXS,
  '__module__' : 'tendermint.mempool.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.mempool.Txs)
  })
_sym_db.RegisterMessage(Txs)

Message = _reflection.GeneratedProtocolMessageType('Message', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGE,
  '__module__' : 'tendermint.mempool.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.mempool.Message)
  })
_sym_db.RegisterMessage(Message)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
